local Addon, private = ...

setfenv(1, private)

-- Private methods
-- ============================================================================

local invokeNavigatorPageChanging = Utility.Event.Create(Addon.identifier, "Navigator.PageChanging")
local invokeNavigatorPageChanged = Utility.Event.Create(Addon.identifier, "Navigator.PageChanged")

local activePages = {
	-- [tostring(page)] = navigator
}

local function addButtonControls(self)
	self.container:GetPageContentFrame():EventAttach(Event.UI.Input.Mouse.Mouse4.Click, function() self:GoBackward() end, tostring(self))
	self.container:GetPageContentFrame():EventAttach(Event.UI.Input.Mouse.Mouse5.Click, function() self:GoForward() end, tostring(self))
end

local function trimTable(t, n)
	for i = n + 1, #t do
		t[i] = nil
	end
end

local function trimStacks(self, n)
	trimTable(self.pathStack, n)
	trimTable(self.moduleStack, n)
	trimTable(self.factoryStack, n)
	trimTable(self.titleStack, n)
	trimTable(self.scrollStack, n)
end

local function numPages(self)
	return #self.pathStack
end

local function runJob(self, job)
	if(self.animating or #self.queue > 0) then
		self.queue[#self.queue + 1] = job
	else
		job()
	end
end

local function runQueue(self)
	if(#self.queue > 0) then
		table.remove(self.queue, 1)()
		if(not self.animating) then
			runQueue(self)
		end
	end
end

local function showPage(self, module, path, n)
	local factory = PageFactoryLocator.GetFactory(module)
	if(factory) then
		local page, title
		if(true) then
			-- TODO: Remove this block  once the game no longer explodes on frame recycling
			page = self.pageCache[module .. "|" .. path]
			title = self.pageTitleCache[module .. "|" .. path]
			if(not (page and title)) then
				page, title = factory:CreatePage(self.container:GetPageContentFrame(), path, self.container:GetContentWidth())
			end
			page:SetVisible(true)
		else
			page, title = factory:CreatePage(self.container:GetPageContentFrame(), path, self.container:GetContentWidth())
		end
		local currentPage = self.container:GetCurrentPage()
		if(page and page ~= currentPage) then
			invokeNavigatorPageChanging(self, module, path, title)
			local animation = self.animated and (n < self.current and "slide out" or "slide in")
			if(currentPage) then
				self.scrollStack[self.current] = self.container:GetContentScrollOffset()
				self.animating = self.animated
				if(true) then
					-- TODO: Remove this block once the game no longer explodes on frame recycling
					self.pageCache[self.moduleStack[self.current] .. "|" .. self.pathStack[self.current]] = currentPage
					self.pageTitleCache[self.moduleStack[self.current] .. "|" .. self.pathStack[self.current]] = self.titleStack[self.current]
					self.container:ShowPage(page, animation, self.scrollStack[n] or 0, function()
						currentPage:SetVisible(false)
						invokeNavigatorPageChanged(self, module, path, title)
						if(self.animating) then
							self.animating = false
							runQueue(self)
						end
					end)
				else
					local recycler = self.factoryStack[#self.factoryStack]
					self.container:ShowPage(page, animation, self.scrollStack[n] or 0, function()
						recycler:RecyclePage(currentPage)
						invokeNavigatorPageChanged(self, module, path, title)
						if(self.animating) then
							self.animating = false
							runQueue(self)
						end
					end)
				end
			else
				self.container:ShowPage(page, animation, 0, function()
					invokeNavigatorPageChanged(self, module, path, title)
				end)
			end
			activePages[tostring(page)] = self
			self.moduleStack[n] = module
			self.pathStack[n] = path
			self.factoryStack[n] = factory
			self.titleStack[n] = title
			self.scrollStack[n] = self.scrollStack[n] or 0
			self.current = n

			self.pageCache[self.moduleStack[n] .. "|" .. self.pathStack[n]] = page
			self.pageTitleCache[self.moduleStack[n] .. "|" .. self.pathStack[n]] = title
		end
	end
end

local function gotoPage(self, n)
	if(n == self.current or n < 1 or n > numPages(self)) then
		return
	end
	local new = n < self.current and (self.current - 1) or (self.current + 1)
	showPage(self, self.moduleStack[new], self.pathStack[new], new)
	runJob(self, function() gotoPage(self, n) end)
end

-- Public methods
-- ============================================================================

-- Push a new page, clearing the history on top of the current page
local function PushPage(self, module, path)
	runJob(self, function()
		local n = self.current + 1
		showPage(self, module, path, n)
		trimStacks(self, n)
	end)
end

-- Push a new page, clearing the history on top of the current page
local function PopPage(self, n)
	runJob(self, function()
		if(numPages(self) <= 1) then
			return
		end
		
		n = tonumber(n) or 1
		n = math.max(1, numPages(self) - n)
		if(n < self.current) then
			gotoPage(self, n)
		end
		trimStacks(self, n)
	end)
end

local function GetPageHistoryDepth(self)
	return numPages(self)
end

local function GetPageHistoryPosition(self)
	return self.current
end

local function GoForward(self)
	runJob(self, function()
		gotoPage(self, self.current + 1)
	end)
end

local function GoBackward(self)
	runJob(self, function()
		gotoPage(self, self.current - 1)
	end)
end

local function GoTo(self, n)
	runJob(self, function()
		gotoPage(self, n)
	end)
end

function Navigator(animated, container)
	local self = {
		animated = animated,
		container = container,
		moduleStack = { },
		pathStack = { },
		factoryStack = { },
		titleStack = { },
		scrollStack = { },
		current = 0,
		animating = false, -- true while a page animation is in progress
		queue = { }, -- Queue up actions
		
		-- TODO: This is a temporary solution, caching ALL frames until the game stops exploding when doing real recycling
		pageCache = {
			-- [module|path] = page
		},
		pageTitleCache = {
			-- [module|path] = title
		},

		GetPageHistoryDepth = GetPageHistoryDepth,
		GetPageHistoryPosition = GetPageHistoryPosition,
		GoBackward = GoBackward,
		GoForward = GoForward,
		GoTo = GoTo,
		PopPage = PopPage,
		PushPage = PushPage,
		ReplacePage = ReplacePage,
	}
	addButtonControls(self)
	
	return self
end

function PushPageFromLink(origin, module, path)
	if(module == "#!copy") then
		ShowCopyDialog(path)
	else
		local navigator = activePages[origin]
		if(navigator) then
			navigator:PushPage(module, path)
		end
	end
end
