local Addon, private = ...

setfenv(1, private)

-- Private methods
-- ============================================================================
--[[
local context = UI.CreateContext("PageBuilderCache")
context:SetVisible(false)
local cacheRoot = UI.CreateFrame("Frame", "PageBuilderCacheRoot", context)
]]
local cached = {
	-- The frames are grouped by their semantic type (e.g. "index", "header1", ...) for less style-resetting work
	-- [type] = { frames }
	h1 = { },
	h2 = { },
	p = { },
	a = { },
	index = { },
}
local cacheRoots = {
}

local function cacheFrame(frame, context)
	local name = frame:GetName()
	frame:SetParent(context)
	if(cached[name]) then
		log("cacheFrame", name)
		cached[name][frame] = true
	else
		local type = frame:GetType()
		log("cacheFrame", type)
		cached[type] = cached[type] or { }
		cached[type][frame] = true
	end
end

local function frameFromCache(type, name, parent, init)
	local cache = cached[name] or cached[type]
	if(cache) then
		local frame = next(cache)
		if(frame) then
			log("frameFromCache", type, name)
			cache[frame] = nil
			frame:ClearAll()
			frame:SetParent(parent)
			return frame
		end
	end
	return nil
end

local function createFrame(type, name, parent, init)
	local frame = frameFromCache(type, name, parent)
	if(not frame) then
		frame = UI.CreateFrame(type, name, parent)
		if(init) then
			init(frame)
		end
	end
	return frame
end

local function recycleChildren(parent, context)
	for frame in pairs(parent:GetChildren()) do
		recycleChildren(frame, context)
		cacheFrame(frame, context)
	end
end

local function recalcHeight(page, padding)
	page:SetHeight(page.bottom:GetBottom() - page:GetTop() + padding)
end

local function prepareStyleTable(style)
	local DefaultStyle = DefaultStyle
	local style2 = {
		padding = style.padding or DefaultStyle.padding,
		h1 = style.h1 or DefaultStyle.h1,
		h2 = style.h2 or DefaultStyle.h2,
		p = style.p or DefaultStyle.p,
		a = style.a or DefaultStyle.a,
		code = style.code or DefaultStyle.code,
	}
	-- Make sure we have required fields
	if(not style2.h1.color) then style2.h1.color = DefaultStyle.h1.color end
	if(not style2.h1.fontSize) then style2.h1.fontSize = DefaultStyle.h1.fontSize end
	if(not style2.h2.color) then style2.h2.color = DefaultStyle.h2.color end
	if(not style2.h2.fontSize) then style2.h2.fontSize = DefaultStyle.h2.fontSize end
	if(not style2.p.color) then style2.p.color = DefaultStyle.p.color end
	if(not style2.p.fontSize) then style2.p.fontSize = DefaultStyle.p.fontSize end
	if(not style2.a.color) then style2.a.color = DefaultStyle.a.color end
	if(not style2.a.deprecated) then style2.a.deprecated = DefaultStyle.a.deprecated end
	if(not style2.code.parameter) then style2.code.parameter = DefaultStyle.code.parameter end
	if(not style2.code.result) then style2.code.result = DefaultStyle.code.result end
	if(not style2.code["nil"]) then style2.code["nil"] = DefaultStyle.code["nil"] end
	-- Make format strings
	local colorFormat = [[<font color="#%s">%%s</font>]]
	style2.code.parameter = string.format(colorFormat, style2.code.parameter)
	style2.code.result = string.format(colorFormat, style2.code.result)
	style2.code["nil"] = string.format(colorFormat, style2.code["nil"])
	return style2
end

local function createWidget(self, page, factory)
	local p = self.pagesInProgress[page]
	local widget, widgetAnchor, widgetPadding = factory()
	
	widget:SetPoint("TOPLEFT", p.anchor, p.topleft, p.left, p.y)
	widget:SetPoint("TOPRIGHT", p.anchor, p.topright, p.right, p.y)

	p.anchor = widgetAnchor
	p.y = widgetPadding + self.style.padding
	p.left = 0
	p.right = 0
	p.topleft = "BOTTOMLEFT"
	p.topright = "BOTTOMRIGHT"
	return widget
end

-- Public methods
-- ============================================================================

local function Freeze(self)
	self.frozen = true
end

local function Unfreeze(self)
	self.frozen = false
end

local function BeginPage(self, parent, module)
	local page = UI.CreateFrame("Frame", "LibWikiPage", parent)
	self.pagesInProgress[page] = {
		anchor = page,
		left = self.style.padding,
		right = -self.style.padding,
		y = self.style.padding,
		topleft = "TOPLEFT",
		topright = "TOPRIGHT",
		module = module,
	}
	page.frozen = false
	return page
end

local function EndPage(self, page)
	local p = self.pagesInProgress[page]
	page.Freeze = function(self)
		self.frozen = true
	end
	if(p.anchor == page) then
		page:SetHeight(1)
		page.Unfreeze = function(self)
			self.frozen = false
		end
	else
		local anchor = createFrame("Frame", "", page)
		anchor:SetVisible(false)
		anchor:SetPoint("TOPLEFT", page, "TOPLEFT")
		anchor:SetPoint("TOPRIGHT", page, "TOPRIGHT")
		anchor:SetPoint("BOTTOM", p.anchor, "BOTTOM")
		anchor:EventAttach(Event.UI.Layout.Size, function()
			if(not page.frozen) then
				page:SetHeight(anchor:GetHeight())
			end
		end, "")
		page.Unfreeze = function(self)
			page:SetHeight(anchor:GetHeight())
			self.frozen = false
		end
	end
	self.pagesInProgress[page] = nil
end

local function BuildHeader1(self, page, title, html)
	local module = self.pagesInProgress[page].module
	return createWidget(self, page, function() return Widgets.h1(page, self.style, module, title, html or false, createFrame) end)
end

local function BuildHeader2(self, page, title, html)
	local module = self.pagesInProgress[page].module
	return createWidget(self, page, function() return Widgets.h2(page, self.style, module, title, html or false, createFrame) end)
end

local function BuildParagraph(self, page, text, html)
	local module = self.pagesInProgress[page].module
	return createWidget(self, page, function() return Widgets.p(page, self.style, module, text, html or false, createFrame) end)
end

local function BuildIndex(self, page, content, html)
	local module = self.pagesInProgress[page].module
	return createWidget(self, page, function() return Widgets.toc(page, self.style, module, content, html or false, createFrame) end)
end

local function BuildFunctionSignatures(self, page, signatures, parameters, results, typeFormatCallback)
	local module = self.pagesInProgress[page].module
	return createWidget(self, page, function() return Widgets.fn(page, self.style, module, signatures, parameters, results, true, typeFormatCallback or function(...) return ... end, createFrame) end)
end

local function BuildKeyValueTable(self, page, t, html)
	local module = self.pagesInProgress[page].module
	return createWidget(self, page, function() return Widgets.kvt(page, self.style, module, t, html or false, createFrame) end)
end

local function RecyclePage(self, page, context)
	cacheRoots[context] = cacheRoots[context] or (function()
		local frame = UI.CreateFrame("Frame", "", context)
		frame:SetPoint("TOPLEFT", UIParent, "TOPRIGHT")
		frame:SetVisible(false)
		return frame
	end)()
	cacheRoots[context] = cacheRoots[context] or { }
	recycleChildren(page, cacheRoots[context])
	cacheFrame(page, cacheRoots[context])
end

function PageBuilder(style)
	return {
		style = prepareStyleTable(style or DefaultStyle),
		pagesInProgress = { },
		
		BeginPage = BeginPage,
		EndPage = EndPage,
		
		BuildHeader1 = BuildHeader1,
		BuildHeader2 = BuildHeader2,
		BuildParagraph = BuildParagraph,
		BuildIndex = BuildIndex,
		BuildFunctionSignatures = BuildFunctionSignatures,
		BuildKeyValueTable = BuildKeyValueTable,
		RecyclePage = RecyclePage,
		UpdateIndex = UpdateIndex,
	}
end
