local Addon, private = ...

setfenv(1, private)

-- Private methods
-- ============================================================================

local function sizeChanged(self, handle)
	if(not self.page) then
		return
	end
	local pageHeight = math.floor(self.page:GetHeight())
	local contentHeight = math.floor(self.content:GetHeight())
	
	if(pageHeight <= contentHeight) then
		self.page:SetPoint("TOP", self.content, "TOP", nil, 0)
		self.scrollbar:SetEnabled(false)
		self.scrollbar:SetRange(0, 0)
	else
		self.scrollbar:SetRange(0, pageHeight - contentHeight)
		self.scrollbar:SetEnabled(true)
		self.scrollbar:SetThickness(pageHeight)
	end
end

local function scrollbarChanged(self)
	if(self.page) then
		self.page:SetPoint("TOP", self.content, "TOP", nil, -self.scrollbar:GetPosition())
	end
end

-- Public methods
-- ============================================================================

local function ShowPage(self, page, animation, scrollOffset, callback)
	scrollOffset = scrollOffset or 0
	local left = (animation == "slide in" and 1 or -1)
	self.scrollbar:SetEnabled(false)
	page:SetVisible(true)
	if(self.page) then
		local old = self.page
		old:Freeze()
		old:ClearPoint("RIGHT")
		old:SetWidth(self.content:GetWidth())
		old:AnimatePoint(animation and self.duration, self.animation, "LEFT", self.content, -left, nil, function()
			old:ClearAll() -- Prevent all invisible pages from resizing
			old:Unfreeze()
			old:SetVisible(false)
		end)
		self.page = page
		page:SetWidth(self.content:GetWidth())
		page:Freeze()
		page:SetPoint("TOPLEFT", self.content, left, 0, 0, -scrollOffset)
		page:AnimatePoint(animation and self.duration, self.animation, "LEFT", self.content, 0, nil, function()
			self.page:ClearWidth()
			self.page:SetPoint("RIGHT", self.content, "RIGHT")
			page:Unfreeze()
			sizeChanged(self, {})
			if(self.scrollbar:GetEnabled()) then
				self.scrollbar:SetPosition(scrollOffset)
			end
			if(type(callback) == "function") then
				callback()
			end
		end)
	else
		self.page = page
		page:SetPoint("TOPLEFT", self.content, "TOPLEFT", 0, -scrollOffset)
		page:SetPoint("RIGHT", self.content, "RIGHT")
		sizeChanged(self, {}, scrollOffset)
		if(self.scrollbar:GetEnabled()) then
			self.scrollbar:SetPosition(scrollOffset)
		end
		if(type(callback) == "function") then
			callback()
		end
	end
end

local function GetContentWidth(self)
	return self.content:GetWidth()
end

local function GetContentHeight(self)
	return self.content:GetWidth()
end

local function GetContentScrollOffset(self)
	return self.scrollbar:GetEnabled() and self.scrollbar:GetPosition() or 0
end

local function GetCurrentPage(self)
	return self.page
end

local function GetPageContentFrame(self)
	return self.content
end

function PageContainer(parent, animation, duration)
	local self = UI.CreateFrame("Frame", "Page Container", parent)
	
	local invisible = UI.CreateFrame("Frame", "", self)
	invisible:SetVisible(false)
	
	local scrollbar = UI.CreateFrame("RiftScrollbar", "", self)
	scrollbar:SetPoint("TOPRIGHT", self, "TOPRIGHT")
	scrollbar:SetPoint("BOTTOMRIGHT", self, "BOTTOMRIGHT")
	scrollbar:SetEnabled(false)
	scrollbar:EventAttach(Event.UI.Scrollbar.Change, function(sb, handle) scrollbarChanged(self) end, "")

	local content = UI.CreateFrame("Mask", "", self)
	content:SetPoint("TOPLEFT", self, "TOPLEFT")
	content:SetPoint("BOTTOMLEFT", self, "BOTTOMLEFT")
	content:SetPoint("TOPRIGHT", scrollbar, "TOPLEFT")
	content:SetPoint("BOTTOMRIGHT", scrollbar, "BOTTOMLEFT")
	content:SetBackgroundColor(0, 0, 0, 0.5)
	content:EventAttach(Event.UI.Input.Mouse.Wheel.Back, function(sb, handle)
		if(scrollbar:GetEnabled()) then
			local _, max = scrollbar:GetRange()
			scrollbar:SetPosition(math.min(scrollbar:GetPosition() + DefaultStyle.p.fontSize * 1.5, max))
		end
	end, "")
	content:EventAttach(Event.UI.Input.Mouse.Wheel.Forward, function(sb, handle)
		if(scrollbar:GetEnabled()) then
			local min = scrollbar:GetRange()
			scrollbar:SetPosition(math.max(scrollbar:GetPosition() - DefaultStyle.p.fontSize * 1.5, min))
		end
	end, "")
	
	self:EventAttach(Event.UI.Layout.Size, sizeChanged, "")
	
	self.scrollbar = scrollbar
	self.content = content
	self.invisible = invisible
	self.animation = animation or "linear"
	self.duration = duration
	
	self.ShowPage = ShowPage
	self.GetContentWidth = GetContentWidth
	self.GetContentHeight = GetContentHeight
	self.GetCurrentPage = GetCurrentPage
	self.GetPageContentFrame = GetPageContentFrame
	self.GetContentScrollOffset = GetContentScrollOffset
	return self
end
